==> tempserver-0.0.1.tar.gz: tempserver-0.0.1/tempserver.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket, re, os, sys, getopt
# pwd

# Constants
PORT = 49000

# sensor related
class Sensor:
    name = "none"

    def get( self, devices ):
        return "NA 0"

class Sensor_hddtempd( Sensor ):
    name = "hddtempd"

    def get( self, devices ):
        """Connects to localhosts hddtemp daemon for hdd temp"""
        def gettemps():
            """Returns (dev, name, temp(int) )"""
            csock = socket.socket( socket.AF_INET, socket.SOCK_STREAM )
            csock.connect( ( "localhost", 7634 ) )
            lines = csock.makefile( 'r' ).readline()
            csock.close()
        
            lines = lines.replace( '||', '|#|' )
            lines = lines.split( '#' )
    
            ret_val = []
            for line in lines:
                dev, name, temp = line[1:-3].split('|')
                dev = dev.replace( "/dev/", "" )
                ret_val.append( (dev, name, int( temp )) )
            return ret_val

        ret_val = ""

        for devline in gettemps():
            if devline[0] in devices:
                ret_val += "%s=%d," %( devline[0], devline[2] )
    
        if ret_val != "":
            return ret_val[:-1]
        return ""


class Sensor_acpi( Sensor ):
    name = "acpi"
    
    def get( self, devices ):
        """Reads termal zone 0"""
        ret_val = ""
        for dev in devices:
            tzline = open( "/proc/acpi/thermal_zone/%s/temperature" % dev,
                           'r' ).readline()
            temp = re.search( "^.*: *(\d+) C$", tzline )
            ret_val += "%s=%s," %( dev, temp.group(1) )

        if ret_val != "":
            return ret_val[:-1]
        return ""

# Service loop of doom
def service_loop( sock ):
    while True:
        channel, client = sock.accept()
        print "connection from %s:%d" % client
        
        for x in selected_devices:
            output_sensor = "NA=0"
            for y in sensors:
                if x[0] == y.name:
                    output_sensor = y.get( x[1] )
            
            channel.send( "%s," %( output_sensor ) )
        channel.send( '\n' )
        channel.close()

## fake /dev/null
class Dev_Null:
    def write( self, s ):
        pass

# -- main --
if __name__ == '__main__':
    print "tempserver v0.0.1"
    print "Copyright (C) 2008  Patrik Lembke"
    print
    daemon = True
    pidfile = "/tmp/tempserver.pid"
    sensors = [ Sensor_acpi(), Sensor_hddtempd() ]
    # selected_devices = [ [ "acpi", [ "TZ0", "TZ1" ] ],
    #                      [ "hddtempd", [ "sda" ] ] ]
    selected_devices = [] # Devices (called sensors on the command line..
    
    # handle arguments hihihi
    opts, free_args = getopt.gnu_getopt( sys.argv[1:], "hfp:s:u:g:",
                                         ( "help", "foreground", "pidfile=",
                                           "sensors=", "user=", "group=" ) )
    for arg, arg_opt in opts:
        if arg in ( "-h", "--help" ):
            print "temperature server for collection tool that isn't yet"
            print
            print "-h, --help\t\tThis text"
            print "-f, --foreground\tKeep in foreground (don't become a daemon)"
            print "-p, --pidfile <file>\tUse pidfile <file>."
            print "-s, --sensors [devs]\tUse sensors"
#            print "-u, --user <user>\t\tRun as user"
            print "\t\t\tExample: acpi,TZ0,TZ4.hddtempd,sda"
            print "\t\t\tAvailable sensors:"
            for sensor in sensors:
                print "\t\t\t\t%s" % sensor.name
            print
            print "Report bugs to <blambi@chebab.com>"
            sys.exit(0)

        elif arg in ( "-f", "--foreground" ):
            daemon = False

        elif arg in ( "-p", "--pidfile" ):
            pidfile = arg_opt

        elif arg in ( "-s", "--sensors" ):
            sens = arg_opt.split( '.' )

            for x in sens:
                sensor, devs = x.split( ',', 1 )
                devs = devs.split( ',' )
                selected_devices.append( [ sensor, devs ] )

#         elif arg in ( "-u", "--user" ):
#             if os.getuid() != 0:
#                 print "Requires root previliges to change uid"
#                 sys.exit( 1 )
#             # Doesn't work under linux kernel
#             new_pwd = pwd.getpwnam( arg_opt )
#             os.setuid( new_pwd[2] )
#             os.setgid( new_pwd[3] )
            
        else:
            print "unkown arg: " + arg
            sys.exit( 1 )

    if len( selected_devices ) == 0:
        print "you must specify at least one sensor to use"
        sys.exit( 1 )
        
    # don't become daemon if ze user don't wish us to
    if daemon:
        print "becoming a daemon!"
        sys.stdout = Dev_Null()
        sys.stderr = Dev_Null()
        pid = os.fork()
        if pid:
            pfile = open( pidfile, "w+" )
            pfile.write( "%d\n" % pid )
            pfile.close()
            os._exit() # Kill our parent!

    # Setup socket
    sock = socket.socket( socket.AF_INET, socket.SOCK_STREAM )
    sock.setsockopt( socket.SOL_SOCKET, socket.SO_REUSEADDR, 1 )
    sock.bind( ( "", PORT ) )
    sock.listen( True )

    print "lisning for trouble on port %d" % PORT


    
    try:
        service_loop( sock )
    except KeyboardInterrupt:
        print "closing socket"
        sock.close()

==> tempserver-0.0.2.tar.gz: tempserver-0.0.2/tempserver.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket, re, os, sys, getopt
# pwd

# Constants
PORT = 49000

# sensor related
class Sensor:
    name = "none"

    def get( self, devices ):
        return "NA=0"

class Sensor_hddtempd( Sensor ):
    name = "hddtempd"

    def get( self, devices ):
        """Connects to localhosts hddtemp daemon for hdd temp"""
        def gettemps():
            """Returns (dev, name, temp(int) )"""
            csock = socket.socket( socket.AF_INET, socket.SOCK_STREAM )
            csock.connect( ( "localhost", 7634 ) )
            lines = csock.makefile( 'r' ).readline()
            csock.close()
        
            lines = lines.replace( '||', '|#|' )
            lines = lines.split( '#' )
    
            ret_val = []
            for line in lines:
                dev, name, temp = line[1:-3].split('|')
                dev = dev.replace( "/dev/", "" )
                ret_val.append( (dev, name, int( temp )) )
            return ret_val

        ret_val = ""

        for devline in gettemps():
            if devline[0] in devices:
                ret_val += "%s=%d," %( devline[0], devline[2] )
    
        if ret_val != "":
            return ret_val[:-1]
        return ""


class Sensor_acpi( Sensor ):
    name = "acpi"
    
    def get( self, devices ):
        """Reads termal zone 0"""
        ret_val = ""
        for dev in devices:
            tzline = open( "/proc/acpi/thermal_zone/%s/temperature" % dev,
                           'r' ).readline()
            temp = re.search( "^.*: *(\d+) C$", tzline )
            ret_val += "%s=%s," %( dev, temp.group(1) )

        if ret_val != "":
            return ret_val[:-1]
        return ""

class Sensor_lm( Sensor ):
    name = "lm"

    def get( self, devices ):
        """This sensor requires a "path" currently
        example: /sys/devices/platform/lm78.656/temp1_input
        is: lm78_656+temp1"""

        ret_val = ""

        for dev in devices:
            t_dev = dev.replace( "_","." ).replace( "+", "/" )
            lmline = open( "/sys/devices/platform/%s_input" %
                           t_dev, 'r' ).readline()
            temp = int( lmline ) / 1000
            ret_val += "%s=%s," %( dev[ dev.find( '+' ) +1 : ], temp )

        if ret_val != "":
            return ret_val[:-1]
        return ""

# Service loop of doom
def service_loop( sock ):
    while True:
        channel, client = sock.accept()
        print "connection from %s:%d" % client
        
        for x in selected_devices:
            output_sensor = "NA=0"
            for y in sensors:
                if x[0] == y.name:
                    output_sensor = y.get( x[1] )
            
            channel.send( "%s," %( output_sensor ) )
        channel.send( '\n' )
        channel.close()

## fake /dev/null
class Dev_Null:
    def write( self, s ):
        pass

# -- main --
if __name__ == '__main__':
    print "tempserver v0.0.2"
    print "Copyright (C) 2008-2009  Patrik Lembke"
    print
    daemon = True
    pidfile = "/tmp/tempserver.pid"
    sensors = [ Sensor_acpi(), Sensor_hddtempd(), Sensor_lm() ]
    
    # selected_devices = [ [ "acpi", [ "TZ0", "TZ1" ] ],
    #                      [ "hddtempd", [ "sda" ] ] ]
    selected_devices = [] # Devices (called sensors on the command line..
    
    # handle arguments hihihi
    opts, free_args = getopt.gnu_getopt( sys.argv[1:], "hfp:s:u:g:",
                                         ( "help", "foreground", "pidfile=",
                                           "sensors=", "user=", "group=" ) )
    for arg, arg_opt in opts:
        if arg in ( "-h", "--help" ):
            print "temperature server for collection tool that isn't yet"
            print
            print "-h, --help\t\tThis text"
            print "-f, --foreground\tKeep in foreground (don't become a daemon)"
            print "-p, --pidfile <file>\tUse pidfile <file>."
            print "-s, --sensors [devs]\tUse sensors"
#            print "-u, --user <user>\t\tRun as user"
            print "\t\t\tExample: acpi,TZ0,TZ4.hddtempd,sda"
            print "\t\t\tAvailable sensors:"
            for sensor in sensors:
                print "\t\t\t\t%s" % sensor.name
            print
            print "Report bugs to <blambi@chebab.com>"
            sys.exit(0)

        elif arg in ( "-f", "--foreground" ):
            daemon = False

        elif arg in ( "-p", "--pidfile" ):
            pidfile = arg_opt

        elif arg in ( "-s", "--sensors" ):
            sens = arg_opt.split( '.' )

            for x in sens:
                sensor, devs = x.split( ',', 1 )
                devs = devs.split( ',' )
                selected_devices.append( [ sensor, devs ] )

#         elif arg in ( "-u", "--user" ):
#             if os.getuid() != 0:
#                 print "Requires root previliges to change uid"
#                 sys.exit( 1 )
#             # Doesn't work under linux kernel
#             new_pwd = pwd.getpwnam( arg_opt )
#             os.setuid( new_pwd[2] )
#             os.setgid( new_pwd[3] )
            
        else:
            print "unkown arg: " + arg
            sys.exit( 1 )

    if len( selected_devices ) == 0:
        print "you must specify at least one sensor to use"
        sys.exit( 1 )
        
    # don't become daemon if ze user don't wish us to
    if daemon:
        print "becoming a daemon!"
        sys.stdout = Dev_Null()
        sys.stderr = Dev_Null()
        pid = os.fork()
        if pid:
            pfile = open( pidfile, "w+" )
            pfile.write( "%d\n" % pid )
            pfile.close()
            os._exit() # Kill our parent!

    # Setup socket
    sock = socket.socket( socket.AF_INET, socket.SOCK_STREAM )
    sock.setsockopt( socket.SOL_SOCKET, socket.SO_REUSEADDR, 1 )
    sock.bind( ( "", PORT ) )
    sock.listen( True )

    print "lisning for trouble on port %d" % PORT


    
    try:
        service_loop( sock )
    except KeyboardInterrupt:
        print "closing socket"
        sock.close()
